
.. automodule:: bci_framework.default_extensions.Resting_state_and_noise_acquisition
   :members:
   :no-undoc-members:
   :no-show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   bci_framework.default_extensions.Resting_state_and_noise_acquisition.main
